@@ -1,6 +1,6 @@
 from datetime import datetime
 
-import db
+import .db
 
 
 class User(db.Model):
